.. _api_core:

flameiq.core — Comparison Engine
==================================

Comparator
----------

.. automodule:: flameiq.core.comparator
   :members:

Models
------

.. automodule:: flameiq.core.models
   :members:

Thresholds
----------

.. automodule:: flameiq.core.thresholds
   :members:

Errors
------

.. automodule:: flameiq.core.errors
   :members:
   :show-inheritance:
